package org.wso2.registry.lifecycle;

import org.wso2.registry.Resource;
import org.wso2.registry.Registry;
import org.wso2.registry.RegistryException;
import org.wso2.registry.jdbc.handlers.RequestContext;

public abstract class Lifecycle {

    public static final String CURRENT_LIFE_CYCLE = "currentPhase";
    public static final String AVAILABLE_LIFE_CYCLES = "AvailablePhases";
    public static final String COMPLETED = "completed";

    private String name;
    private int location;

    public String getName() {
        return name;
    }


    public void setName(String name) {
        this.name = name;
    }

    /**
     * Associate a new Resource with this lifecycle.  This could set custom properties, create
     * sub-directories, etc...  If this throws an Exception, the association has FAILED.
     *
     * @param resource Resource which we want to change the state
     * @param registry Current registry instance
     * @throws org.wso2.registry.RegistryException
     *          If the condition is not met or some thing is wrong
     */
    public abstract void associate(Resource resource, Registry registry) throws RegistryException;

    /**
     * Do something (change state) - action names are lifecycle-specific, and it's up to the
     * implementation to decide if a given transition is allowed, and what to do if so.
     *
     * @param context the RequestContext containing all the state about this request
     * @param action  action to perform
     * @throws org.wso2.registry.RegistryException
     *          If the condition is not met or some thing is wrong
     */
    public abstract void transition(RequestContext context, String action) throws RegistryException;
}
